//
// zedit - simple text editor
// Copyright (C) 2004-2005 Bryan Beicker <tokiko@tokiko.net>
//
// This file is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License (Version 2)
// as published by the Free Software Foundation.
//
// This file is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//

#include <gtk/gtk.h>		// gtk
#include "question.xpm"
#include "cancel.xpm"
#include "error.xpm"
#include "save.xpm"
#include "close.xpm"
#include "main.h"


void dialog_button_clicked(GtkButton * button, gpointer data)
{
	gtk_dialog_response(GTK_DIALOG(dialog), GPOINTER_TO_INT(data));
}


void about_dialog(GtkWidget * parent, char ** xpm, char * name, char * desc, char * copy)
{
	dialog = gtk_dialog_new_with_buttons("about", GTK_WINDOW(parent), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CLOSE, GTK_RESPONSE_NONE, NULL);
	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
	
	GdkPixbuf * pixbuf;
	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) xpm);
	
	GtkWidget * table;
	table = gtk_table_new(3, 2, FALSE);
	gtk_table_set_row_spacings(GTK_TABLE(table), 2);
	gtk_table_set_col_spacings(GTK_TABLE(table), 4);
	gtk_container_set_border_width(GTK_CONTAINER(table), 12);
	gtk_widget_show(table);

	GtkWidget * icon;
	icon = gtk_image_new_from_pixbuf(pixbuf);
	gdk_pixbuf_unref(pixbuf);
	gtk_misc_set_alignment(GTK_MISC(icon), 1, 0.5);
	gtk_widget_show(icon);
	gtk_table_attach(GTK_TABLE(table), icon, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);
	
	gchar * tmp;
	GtkWidget * version;
	version = gtk_label_new(NULL);
	tmp = g_strdup_printf("<span weight=\"bold\" size=\"larger\">%s</span>", name);
	gtk_label_set_text(GTK_LABEL(version), tmp);
	g_free(tmp);
	gtk_misc_set_alignment(GTK_MISC(version), 0, 0.5);
	gtk_label_set_use_markup(GTK_LABEL(version), TRUE);
	gtk_widget_show(version);
	gtk_table_attach(GTK_TABLE(table), version, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
	
	GtkWidget * description;
	description = gtk_label_new(desc);
	gtk_widget_show(description);
	gtk_table_attach(GTK_TABLE(table), description, 0, 2, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
	
	GtkWidget * copyright;
	tmp = g_strdup_printf("<span size=\"smaller\">%s</span>", copy);
	copyright = gtk_label_new(tmp);
	g_free(tmp);
	gtk_label_set_use_markup(GTK_LABEL(copyright), TRUE);
	gtk_widget_show(copyright);
	gtk_table_attach(GTK_TABLE(table), copyright, 0, 2, 2, 3, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
	
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
	gtk_dialog_run(GTK_DIALOG(dialog));
	gtk_widget_destroy(dialog);
}


int save_question_dialog(GtkWidget * parent)
{
	int rc;
	
	dialog = gtk_dialog_new();
	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(parent));
	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), TRUE);
	gtk_window_set_title(GTK_WINDOW(dialog), "");
	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
	
	GdkPixbuf * pixbuf;
	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) question_xpm);
	
	GtkWidget * vbox_table;
	vbox_table = gtk_table_new(1, 1, FALSE);
	gtk_widget_show(vbox_table);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox_table);
	
	GtkWidget * body_alignment;
	body_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
	gtk_widget_show(body_alignment);
	gtk_table_attach(GTK_TABLE(vbox_table), body_alignment, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);
	
	GtkWidget * body_table;
	body_table = gtk_table_new(1, 2, FALSE);
	gtk_table_set_col_spacings(GTK_TABLE(body_table), 8);
	gtk_container_set_border_width(GTK_CONTAINER(body_table), 8);
	gtk_widget_show(body_table);
	gtk_container_add(GTK_CONTAINER(body_alignment), body_table);

	GtkWidget * icon;
	icon = gtk_image_new_from_pixbuf(pixbuf);
	gdk_pixbuf_unref(pixbuf);
	gtk_misc_set_alignment(GTK_MISC(icon), 1, 0.5);
	gtk_widget_show(icon);
	gtk_table_attach(GTK_TABLE(body_table), icon, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);
	
	GtkWidget * body_label;
	body_label = gtk_label_new("<span weight=\"bold\" size=\"larger\">save changes?</span>");
	gtk_label_set_use_markup(GTK_LABEL(body_label), TRUE);
	gtk_widget_show(body_label);
	gtk_table_attach(GTK_TABLE(body_table), body_label, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	GtkWidget * action_table;
	action_table = gtk_table_new(1, 1, TRUE);
	gtk_widget_show(action_table);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area), action_table);

	GtkWidget * action_alignment;
	action_alignment = gtk_alignment_new(1.0, 0.5, 0, 0);
	gtk_widget_show(action_alignment);
	gtk_table_attach(GTK_TABLE(action_table), action_alignment, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);

	GtkWidget * buttons_table;
	buttons_table = gtk_table_new(1, 3, TRUE);
	gtk_table_set_col_spacings(GTK_TABLE(buttons_table), 8);
	gtk_widget_show(buttons_table);
	gtk_container_add(GTK_CONTAINER(action_alignment), buttons_table);

	GtkWidget * dont_save_button;
	GtkWidget * dont_save_hbox;
	GtkWidget * dont_save_label;
	dont_save_button = gtk_button_new();
	dont_save_hbox = gtk_hbox_new(FALSE, 4);
	dont_save_label = gtk_label_new("don't save");
	gtk_widget_show(dont_save_button);
	gtk_widget_show(dont_save_hbox);
	gtk_widget_show(dont_save_label);
	gtk_box_pack_end(GTK_BOX(dont_save_hbox), dont_save_label, FALSE, FALSE, 0);
	gtk_container_add(GTK_CONTAINER(dont_save_button), dont_save_hbox);
	gtk_table_attach(GTK_TABLE(buttons_table), dont_save_button, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
	
	GtkWidget * cancel_button;
	GtkWidget * cancel_alignment;
	GtkWidget * cancel_hbox;
	GtkWidget * cancel_label;
	GdkPixbuf * cancel_pixbuf;
	GtkWidget * cancel_icon;
	cancel_button = gtk_button_new();
	cancel_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
	cancel_hbox = gtk_hbox_new(FALSE, 4);
	cancel_label = gtk_label_new("cancel");
	cancel_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) cancel_xpm);
	cancel_icon = gtk_image_new_from_pixbuf(cancel_pixbuf);
	gtk_container_set_border_width(GTK_CONTAINER(cancel_hbox), 2);
	gdk_pixbuf_unref(cancel_pixbuf);
	gtk_widget_show(cancel_button);
	gtk_widget_show(cancel_alignment);
	gtk_widget_show(cancel_hbox);
	gtk_widget_show(cancel_label);
	gtk_widget_show(cancel_icon);
	gtk_box_pack_end(GTK_BOX(cancel_hbox), cancel_label, FALSE, FALSE, 0);
	gtk_box_pack_end(GTK_BOX(cancel_hbox), cancel_icon, FALSE, FALSE, 0);
	gtk_container_add (GTK_CONTAINER(cancel_alignment), cancel_hbox);
	gtk_container_add(GTK_CONTAINER(cancel_button), cancel_alignment);
	gtk_table_attach(GTK_TABLE(buttons_table), cancel_button, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

	GtkWidget * save_button;
	GtkWidget * save_alignment;
	GtkWidget * save_hbox;
	GtkWidget * save_label;
	GdkPixbuf * save_pixbuf;
	GtkWidget * save_icon;
	save_button = gtk_button_new();
	save_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
	save_hbox = gtk_hbox_new(FALSE, 4);
	save_label = gtk_label_new("save");
	save_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) save_xpm);
	save_icon = gtk_image_new_from_pixbuf(save_pixbuf);
	gtk_container_set_border_width(GTK_CONTAINER(save_hbox), 2);
	gdk_pixbuf_unref(save_pixbuf);
	gtk_widget_show(save_button);
	gtk_widget_show(save_alignment);
	gtk_widget_show(save_hbox);
	gtk_widget_show(save_label);
	gtk_widget_show(save_icon);
	gtk_box_pack_end(GTK_BOX(save_hbox), save_label, FALSE, FALSE, 0);
	gtk_box_pack_end(GTK_BOX(save_hbox), save_icon, FALSE, FALSE, 0);
	gtk_container_add(GTK_CONTAINER(save_alignment), save_hbox);
	gtk_container_add(GTK_CONTAINER(save_button), save_alignment);
	gtk_table_attach(GTK_TABLE(buttons_table), save_button, 2, 3, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
	gtk_widget_grab_focus(save_button);

	gtk_signal_connect(GTK_OBJECT(dont_save_button), "clicked", GTK_SIGNAL_FUNC(dialog_button_clicked), GINT_TO_POINTER(ZGTK_DIALOG_DONT_SAVE));
	gtk_signal_connect(GTK_OBJECT(cancel_button), "clicked", GTK_SIGNAL_FUNC(dialog_button_clicked), GINT_TO_POINTER(ZGTK_DIALOG_CANCEL));
	gtk_signal_connect(GTK_OBJECT(save_button), "clicked", GTK_SIGNAL_FUNC(dialog_button_clicked), GINT_TO_POINTER(ZGTK_DIALOG_SAVE));

	rc = gtk_dialog_run(GTK_DIALOG(dialog));
	gtk_widget_destroy(dialog);
	
	return rc;
}


int error_dialog(GtkWidget * parent, gchar * text)
{
	int rc;
	
	dialog = gtk_dialog_new();
	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(parent));
	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), TRUE);
	gtk_window_set_title(GTK_WINDOW(dialog), "");
	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
	
	GdkPixbuf * pixbuf;
	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) error_xpm);
	
	GtkWidget * vbox_table;
	vbox_table = gtk_table_new(1, 1, FALSE);
	gtk_widget_show(vbox_table);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox_table);
	
	GtkWidget * body_alignment;
	body_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
	gtk_widget_show(body_alignment);
	gtk_table_attach(GTK_TABLE(vbox_table), body_alignment, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);
	
	GtkWidget * body_table;
	body_table = gtk_table_new(1, 2, FALSE);
	gtk_table_set_col_spacings(GTK_TABLE(body_table), 8);
	gtk_container_set_border_width(GTK_CONTAINER(body_table), 8);
	gtk_widget_show(body_table);
	gtk_container_add(GTK_CONTAINER(body_alignment), body_table);

	GtkWidget * icon;
	icon = gtk_image_new_from_pixbuf(pixbuf);
	gdk_pixbuf_unref(pixbuf);
	gtk_misc_set_alignment(GTK_MISC(icon), 1, 0.5);
	gtk_widget_show(icon);
	gtk_table_attach(GTK_TABLE(body_table), icon, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);
	
	GtkWidget * body_label;
	gchar * body;
	body = g_strdup_printf("<span weight=\"bold\" size=\"larger\">%s</span>", text);
	body_label = gtk_label_new(body);
	g_free(body);
	gtk_label_set_use_markup(GTK_LABEL(body_label), TRUE);
	gtk_widget_show(body_label);
	gtk_table_attach(GTK_TABLE(body_table), body_label, 1, 2, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);

	GtkWidget * action_table;
	action_table = gtk_table_new(1, 1, TRUE);
	gtk_widget_show(action_table);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->action_area), action_table);

	GtkWidget * action_alignment;
	action_alignment = gtk_alignment_new(1.0, 0.5, 0, 0);
	gtk_widget_show(action_alignment);
	gtk_table_attach(GTK_TABLE(action_table), action_alignment, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 2);

	GtkWidget * buttons_table;
	buttons_table = gtk_table_new(1, 1, TRUE);
	gtk_table_set_col_spacings(GTK_TABLE(buttons_table), 8);
	gtk_widget_show(buttons_table);
	gtk_container_add(GTK_CONTAINER(action_alignment), buttons_table);

	GtkWidget * close_button;
	GtkWidget * close_alignment;
	GtkWidget * close_hbox;
	GtkWidget * close_label;
	GdkPixbuf * close_pixbuf;
	GtkWidget * close_icon;
	close_button = gtk_button_new();
	close_alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
	close_hbox = gtk_hbox_new(FALSE, 4);
	close_label = gtk_label_new("close");
	close_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) close_xpm);
	close_icon = gtk_image_new_from_pixbuf(close_pixbuf);
	gtk_container_set_border_width(GTK_CONTAINER(close_hbox), 2);
	gdk_pixbuf_unref(close_pixbuf);
	gtk_widget_show(close_button);
	gtk_widget_show(close_alignment);
	gtk_widget_show(close_hbox);
	gtk_widget_show(close_label);
	gtk_widget_show(close_icon);
	gtk_box_pack_end(GTK_BOX(close_hbox), close_label, FALSE, FALSE, 0);
	gtk_box_pack_end(GTK_BOX(close_hbox), close_icon, FALSE, FALSE, 0);
	gtk_container_add(GTK_CONTAINER(close_alignment), close_hbox);
	gtk_container_add(GTK_CONTAINER(close_button), close_alignment);
	gtk_table_attach(GTK_TABLE(buttons_table), close_button, 0, 1, 0, 1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
	gtk_widget_grab_focus(close_button);

	gtk_signal_connect(GTK_OBJECT(close_button), "clicked", GTK_SIGNAL_FUNC(dialog_button_clicked), GINT_TO_POINTER(ZGTK_DIALOG_CLOSE));

	rc = gtk_dialog_run(GTK_DIALOG(dialog));
	gtk_widget_destroy(dialog);
	
	return rc;
}
